<?php
require_once 'lib/list_util.php';

require_once 'lib/youtube.php';
require_once 'lib/vk.php';
require_once 'lib/tvigle.php';
require_once 'lib/veterok.php';
require_once 'lib/mill.php';

require_once 'Smotroon_vod_category.php';
require_once 'Smotroon_movie.php';
require_once 'Smotroon_movie_series.php';

class SmotroonApi
{

    public static function html2txt($document){ 
        $search = array('@<script[^>]*?>.*?</script>@si',   // Strip out javascript 
                   '@<[\/\!]*?[^<>]*?>@si',                 // Strip out HTML tags 
                   '@<style[^>]*?>.*?</style>@siU',         // Strip style tags properly 
                   '@<![\s\S]*?--[ \t\n\r]*>@'              // Strip multi-line comments including CDATA 
        ); 
        $newline = array('@</p>@si',                        // Replace </p> to ' '
                        '@<br[^>]*?>@si'                    // Replace <br*> to ' '
        );
        $document = preg_replace($search, '', $document); 
        $document = preg_replace($newline, ' ', $document); 

        return preg_replace('@\s+@', ' ', $document);       // Perlace multiple spaces to only one
    } 

    public static function smotroon_exception($e, $def_caption = 'Error', $is_playback = false)
    {
        $is_smotroon_error = ($e instanceof SmotroonException);
        if (!$is_smotroon_error)
        {
            hd_print('General exception: ' . $e->getMessage());
            $title = !$is_playback ? 'Ошибка' :
                'Не удалось поключиться к Интернету';
            $text_lines = $is_playback ? array() :
                array(
                 'Не удалось поключиться к Интернету.',
                 'Проверьте наличие подключения.'
                );
            return new DuneException(
                $def_caption, -1,
                ActionFactory::show_error(false, $title, $text_lines));
        }
        hd_print('Smotroon exception: ' . 'code=' . $e->getCode() . ', message=' . $e->getMessage());

        $ecode = $e->getCode();
        $fatal = false;//$ecode == -1;

        $title = !$is_playback ? 'Ошибка ' . $ecode  : $e->getMessage();
        $text_lines = $is_playback ? array() :
            array($e->getMessage());
        return new DuneException(
            $def_caption, $ecode,
            ActionFactory::show_error($fatal, $title, $text_lines));
    }

    // Возвращает следующий видеообъект из переданной строки.
    // !!! ИЗМЕНЯЕТ ПЕРЕДАННЫЙ ПАРАМЕТР
    private static function get_next_videoobject(&$content)
    {
        $pos = array();

        if (($i = stripos($content, '<object ')) !== false)
            $pos['object'] = $i;

        if (($i = stripos($content, '<embed ')) !== false)
            $pos['embed'] = $i;

        if (($i = stripos($content, '<iframe ')) !== false)
            $pos['iframe'] = $i;

        if (count($pos) < 1)
            return false;

        asort($pos);

        $first = key($pos);

        $content = substr($content, $pos[$first]);

        $close = '</' . $first . '>';
        if (($i = stripos($content, $close)) === false)
        {
            $video = $content;
            $content = "";
            return $video;
        }

        $video = stristr($content, $close, true) . $close;
        $content = substr($content, $i + strlen($close));

        return $video;
    }

    // Возвращает массив видеообъектов из спойлера
    private static function get_spoiler_videos($content)
    {
        $tmp = explode('class="accordion-inner"', $content);

        if (count($tmp) > 1) // Есть спойлер
            $tmp = strstr($tmp[1], '>');
        else
            $tmp = $tmp[0]; //Нет спойлера

        $t = stristr($tmp,'<div class="videoobject"', true);
        if ($t === false)
            $t = $tmp;

        $video_array = array();

        while(($tmp = self::get_next_videoobject($t)) !== false)
            $video_array[] = $tmp;

        return $video_array;

        return false;
    }
    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              VIDEO List
    //
    private static function get_series($video_id, $page, &$series, &$is_has_new, &$plugin_cookies)
    {
        $tmp = explode('<div class="element element-video', $page);
        $tmp = explode('<div class="element element-vkontaktecomments', $tmp[1]);
        $videos = explode('<div class="videoobject"', $tmp[0]);

        unset($videos[0]);
        $n = 0;

        foreach ($videos as $video) {
            $link = "";
            $title = "Видео ";

            //get link
            $tmp = explode('class="accordion-toggle"', $video);

            if (count($tmp) > 1) {
                $tmp = strstr($tmp[1], '>');
                $title = substr(stristr($tmp, '</a>', true), 1);
            }
            else
                $video = substr($video, 1);

            if (($vids = self::get_spoiler_videos($video)) === false) {
                return false;
            }

            if (count($vids) > 1)
            {
                $i = 1;
                foreach($vids as $link)
                {
                    $episode = new SmotroonMovieSeries($n++);
                    $episode->name = HD::str_remove_spec(self::clear($title . ' (часть ' . $i++ . ')'));
                    $episode->playback_url = "http://mp4://" . urlencode($link);
                    $episode->playback_url_is_stream_url = false;

                    array_push
                    (
                        $series,
                        $episode
                    );
                }
            }
            elseif (count($vids) == 1)
            {
                //hd_print($title . " - " .  $link);

                $episode = new SmotroonMovieSeries($n++);
                $episode->name = HD::str_remove_spec(self::clear($title));
                $episode->playback_url = "http://mp4://" . urlencode($vids[0]);
                $episode->playback_url_is_stream_url = false;

                array_push
                (
                    $series,
                    $episode
                );
            }
        }

        return (count($series) == 0) ? false : true;
    }

    private static function parse_video_page($video_id, &$items, $from_fav, $plugin_cookies, $page = '', $video_page_ref = '')
    {
        
        $api = SmotroonConfig::PLUGIN_SITE_MAINPAGE;
        
        if ($video_id != -1)
        {
            $video_page_ref = sprintf(SmotroonConfig::MOVIE_PAGE_URL_FORMAT, $video_id);
            
            // download category video page
            try
            {
                $page = HD::http_get_document($video_page_ref, null, $errcode);
            }
            catch(Exception $e)
            {
                if ($errcode == 404) // У фильма изменился alias
                {
                    return false;
                }
                throw self::smotroon_exception($e, 'No Internet');
            }
        }

        // get playlist
        //ToDo
        $sub_view = false;

        // get image
        $video_image = "";
        $tmp = explode('<div class="thumbnail">', $page);
        if (count($tmp) == 1) // На этой странице нет фильмов
        {
            return false;
        }

        $tmp = explode('<img src="',$tmp[1]);
        if (count($tmp) > 1)
        {
            $video_image = substr($tmp[1], 0, strpos($tmp[1], '"'));
        }

        // get video title
        $video_title = "";
        $tmp = explode('<h1 class="pos-title">', $page);
        if (count($tmp) > 1)
        {
            $tmp = explode('</h1>', $tmp[1]);
            $video_title = $tmp[0];
            //hd_print("--->>> TITLE: " . $video_title);
        }
        else
        {
            hd_print("--->>> NO TITLE!!!");
            return false;
        }

        // original title
        $original_title = "";
        $tmp = explode('<h2 class="pos-subtitle">', $page);
        if (count($tmp) > 1)
        {
            $tmp = explode('</h2>', $tmp[1]);
            $original_title = $tmp[0];
            //hd_print("--->>> ORIGINAL TITLE: " . $original_title);
        }

        $is_has_new = false;

        // get series count
        $n_series = 0;
        $series = false;

        // download playlist
    hd_print("getting series...");
        $series = array();
        $links_exist = SmotroonApi::get_series($video_id, $page, $series, $is_has_new, $plugin_cookies);
        // no valid links
        if ($links_exist === false) {
            hd_print("no series!");
            throw new DuneException(
                "No series", 2,
                ActionFactory::show_error(false, 'Нет видео', array('В этом фильме нет видео.','Возможно он находится в категории \'Ожидаемые\'.')));
            return false;
        }
        hd_print("getting series...done");
        // get description block
        $descr_block = '';
        $tmp = explode('<div class="wrapper-specification">', $page);
        if (count($tmp) > 1)
        {
            $tmp = explode('class="pos-bottom"', $tmp[1]);
            $descr_block = $tmp[0];
            //$descr_block = preg_replace("/(<b>|<\/b>|<font color='\S\S\S\S\S\S\S'>|<\/font>|<i>|<\/i>|<u>|<\/u>)/i", "", $descr_block);

            // year
            $year = '';
            $tmp = explode("<dt>Год</dt><dd", $descr_block);
            if (count($tmp) > 1)
            {
                $tmp = explode('">', $tmp[1]);
                $year = trim(strstr($tmp[1], '</dd>', true));
                //hd_print("--->>> Year: $year");
            }

            // genre
            $genre = '';
            $tmp = explode('<dt>Категория</dt><dd class="element element-itemcategory">', $descr_block);
            if (count($tmp) > 1)
            {
                $tmp = explode('</dd>', $tmp[1]);

                $g = explode('</a',$tmp[0]);
                unset($g[count($g)-1]);
                foreach($g as $t)
                {
                    if (strpos($t, 'class="category-year"')!==false)
                        continue;
                    $tmp = explode('">', $t);
                    if ($genre)
                        $genre .= ', ';
                    $genre .= $tmp[1];
                }
                //hd_print("--->>> Genre: $genre");
            }

            // country
            $country = '';
            $tmp = explode("<dt>Страна</dt><dd", $descr_block);
            if (count($tmp) > 1)
            {
                $tmp = explode('">', $tmp[1]);
                $country = trim(strstr($tmp[1], '</dd>', true));
                //hd_print("--->>> Country: $country");
            }

            // director
            $director = '';
            $tmp = explode("<dt>Режиссер</dt><dd", $descr_block);
            if (count($tmp) > 1)
            {
                $tmp = explode('">', $tmp[1]);
                $director = trim(strstr($tmp[1], '</dd>', true));
                //hd_print("--->>> Director: $director");
            }

            // duration
            $duration = '';
            $duration_min = '';
            $tmp = explode("<dt>Время</dt><dd", $descr_block);
            if (count($tmp) > 1)
            {
                $tmp = explode('">', $tmp[1]);
                $duration = trim(strstr($tmp[1], '</dd>', true));
                //hd_print("--->>> Duration: $duration");
                /*
                // XXX мин format
                if (preg_match("/(\d*)(.*)мин/i", $duration, $tmp))
                {
                    preg_match("/(\d*)/i", $tmp[0], $tmp);
                    $duration_min = $tmp[0];
                }
                // XX:XX:XX format
                else if (preg_match("/\d\d:\d\d:\d\d/i", $duration, $tmp))
                {
                    $tmp = $tmp[0];
                    $duration_min = ($tmp[0]*10+$tmp[1])*60+($tmp[3]*10+$tmp[4]);
                }*/
            }

            // $actors
            $actors = '';
            $tmp = explode("<h3>В ролях</h3>", $descr_block);
            if (count($tmp) > 1)
            {
                $tmp = explode('<div class="element', $tmp[1]);
                $actors = $tmp[0];
                //$actors = preg_replace("/(<div>|<\/div>|<p>|<\/p>|<b>|<\/b>|<font color='\S\S\S\S\S\S\S'>|<\/font>|<i>|<\/i>|<u>|<\/u>)/i", "", $tmp[0]);
                $actors = self::html2txt($actors);
                //hd_print("--->>> Actors: $actors");
            }

            // $description
            $description = '';
            $tmp = explode("<h3>Описание</h3>", $descr_block);
            if (count($tmp) > 1)
            {
                $tmp = explode('</div>', $tmp[1]);
                $description = $tmp[0];
                //$description = preg_replace("/(<div>|<\/div>|<p>|<\/p>|<b>|<\/b>|<font color='\S\S\S\S\S\S\S'>|<\/font>|<i>|<\/i>|<u>|<\/u>)/i", "", $tmp[0]);
                $description = self::html2txt($description);
                //hd_print("--->>> Description: $description");
            }
        }
        
        // push video in to videos list
        $movie = new SmotroonMovie(HD::str_remove_spec($video_id));

        $movie->has_new_series = $is_has_new;
        
        if ($sub_view)
        {
            $movie->set_sub_view($sub_view);
        }
        
        $movie->set_data
        (
            HD::str_remove_spec(self::clear($video_title)),
            HD::str_remove_spec(self::clear($original_title)),
            HD::str_remove_spec(self::clear($description)),
            HD::str_remove_spec($video_image),
            $duration_min,
            HD::str_remove_spec(self::clear($year)),
            HD::str_remove_spec(self::clear($director)),
            '',// $scenarios_str
            HD::str_remove_spec(self::clear($actors)),
            HD::str_remove_spec(self::clear($genre)),
            '',// $rate_imdb,
            '',// $rate_kinopoisk,
            '',// $rate_mpaa,
            HD::str_remove_spec(self::clear($country)),
            '' // $budget
        );

        if ($series)
        {
            foreach ($series as $s)
            {
                $movie->add_episode($s);
            }
        }
        array_push
        (
            $items,
            $movie
        );
        
        return true;
    }

    private static function parse_page($url, &$items, $from_fav, $plugin_cookies)
    {
        hd_print("--->>> parse_page: $url");

        // download category (sub_view) video page
        try
        {
            $doc = HD::http_get_document($url);
        }
        catch(Exception $e)
        {
            throw self::smotroon_exception($e, 'No Internet');
        }
        
        if (is_null($doc))
            return false;

        // get list of videos
        $tmp = explode('<div class="zrow first-zrow row">', $doc);

        if (count($tmp) > 1)
        {
            $tmp = explode('<div class="pagination', $tmp[1]);
            $tmp = $tmp[0];
            $videos = explode('<a class="thumbnail" href="/item/', $tmp);
            unset($videos[0]);
            $videos = array_values($videos);
        }
        else
        {
            return SmotroonApi::parse_video_page(-1, $items, $from_fav, $plugin_cookies, $doc, $url);
        }

        // iterate through videos
        foreach($videos as $video)
        {
            // get video page ref = video id
            $video_id = strstr($video, '"', true);

            // remove category id
            if (($q = strpos($video_id, '?')) !== false)
                $video_id = substr($video_id, 0, $q);

            // get video title
            $video_title = explode('title="', $video);
            $video_title = strstr($video_title[1], '"', true);

            // get poster
            $poster = explode('img src="', $video);
            $poster = strstr($poster[1], '"', true);

            // get year if exist
            $year = explode('<span class="year">', $video);
            if (count($year)>1) {
                $year = explode('</span>', $year[1]);
                $year = trim($year[0]);
            }
            else
                $year = '';

            // push video in videos list
            $movie = new SmotroonMovie(HD::str_remove_spec($video_id));
            $movie->name = HD::str_remove_spec(self::clear($video_title));
            $movie->poster_url = $poster;
            $movie->year = HD::str_remove_spec(self::clear($year));
            array_push
            (
                $items,
                $movie
            );
        }
        
    }

    private static function parse_search_page($url, &$items, $from_fav, $plugin_cookies)
    {
        hd_print("--->>> parse_search_page: $url");

        // download category (sub_view) video page
        try
        {
            $doc = HD::http_get_document($url);
        }
        catch(Exception $e)
        {
            throw self::smotroon_exception($e, 'No Internet');
        }

        if (is_null($doc))
            return false;

        // get list of videos
        $tmp = explode('<dl class="search-results">', $doc);

        if (count($tmp) > 1)
        {
            $tmp = explode('<div class="pagination', $tmp[1]);
            $tmp = $tmp[0];
            $videos = explode('<a href="/item/', $tmp);
            unset($videos[0]);
            $videos = array_values($videos);
        }
        else
        {
            return false;//SmotroonApi::parse_video_page(-1, $items, $from_fav, $plugin_cookies, $doc, $url);
        }

        // iterate through videos
        foreach($videos as $video)
        {
            // get video page ref
            $tmp = explode('"', $video);

            // get video id
            $video_id = $tmp[0];

            // get poster
            $tmp = explode('data-poster="', $video);
            $tmp = explode('"',$tmp[1]);
            $poster = $tmp[0];

            // get title
            $tmp = explode('">', $video);
            $tmp = explode('</a>', $tmp[1]);
            $tmp = $tmp[0];
            $b = strrpos($tmp, '(');
            $video_title = trim(substr($tmp, 0, $b));

            // get year
            $year = trim(substr($tmp, $b + 1 , strrpos($tmp, ')') - $b - 1));

            // push video in to videos list
            $movie = new SmotroonMovie(HD::str_remove_spec($video_id));

            $movie->name = self::clear($video_title);
            $movie->poster_url = $poster;
            $movie->year = $year;
            array_push
            (
                $items,
                $movie
            );
        }
    }

    public static function get_items($start_url, &$m_feed, $category_id, $from_fav, &$plugin_cookies)
    {
        if ($start_url)
        {
            $url = $start_url;
            // select page
            if ($m_feed > 0)
                $url .= "/" . ($m_feed + 1);
        }
        else
        {
            $url_mask = SmotroonConfig::MOVIE_LIST_URL_FORMAT;
            
            // select page
            if ($m_feed > 0)
                $url_mask .= "/" . ($m_feed + 1);
                
            $url = sprintf($url_mask, $category_id);
        }

        ++$m_feed;
        
        $items = array();

        SmotroonApi::parse_page($url, $items, $from_fav, $plugin_cookies);
        
        return $items;
    }

    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              VIDEO Category List
    //

    private static function fill_categories($videos, &$category_index)
    {
        $category_list = array();

        $cat = new SmotroonVodCategory
            (
                'all',
                'Все фильмы',
                '',
                0
            );
        $category_list[] = $cat;
        $category_index[$cat->get_id()] = $cat;

        // iterate through categories
        foreach($videos as $video)
        {
            // get category id
            $tmpm = explode('category/', $video);
            $tmp = explode('">', $tmpm[1]);

            $category_id = $tmp[0];

            // get category title
            $tmp = explode('">', $tmpm[1]);
            $tmp = explode('</a>', $tmp[1]);
            $category_name = $tmp[0];

            // get category view reference
            $category_ref = "category/" . $category_id;

            // get category items count
            $category_items_count = 0;

            $cat =
                new SmotroonVodCategory
                (
                    $category_id,
                    $category_name,
                    $category_ref,
                    $category_items_count
                );

            $category_list[] = $cat;

            $category_index[$cat->get_id()] = $cat;
        }
        
        return $category_list;
    }

    ///////////////////////////////////////////////////////////////////////

    public static function get_categories($category_type, &$category_index)
    {
        $category_url = '';
        switch($category_type)
        {
        case 'vod_categories':
        //case '/ru/video':
            $category_url       = SmotroonConfig::VOD_CATEGORIES_URL;
            $delimiter          = SmotroonConfig::VOD_CATEGORIES_DELIMITER;
            $delimiter_start    = SmotroonConfig::VOD_CATEGORIES_DELIMITER_START;
            $delimiter_end      = SmotroonConfig::VOD_CATEGORIES_DELIMITER_END;
            break;
          default:
            hd_print("!!! Default branch executed !!!");
            return false;
            //$category_url     = 'http://www.ex.ua' . $category_type;
            //$delimiter        = SmotroonConfig::VOD_LANGUAGES_CATEGORY_DELIMITER;
            break;
        }
        try
        {
            $doc = HD::http_get_document($category_url);
        }
        catch(Exception $e)
        {
            throw self::smotroon_exception($e, 'No Internet');
        }
     
        if (is_null($doc))
            return false;//throw new Exception('Can not fetch playlist');

        // get list of categories
        $videos = explode($delimiter_start, $doc);
        $videos = explode($delimiter_end, $videos[1]);
        $videos = explode($delimiter, $videos[0]);
        unset($videos[0]);

        $videos = array_values($videos);
        
        hd_print("--->>> $category_type categories count: " . count($videos));

        return SmotroonApi::fill_categories($videos, $category_index);
    }

    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              VIDEO Search
    //
    
    public static function search_get_items($search_text, &$m_feed, $category_id, $from_fav, &$plugin_cookies)
    {
        hd_print("--->>> search for: $search_text");
        $search_text = urlencode($search_text);
        $items = array();
        $url = false;
        if ($category_id)
        {
            return $items;
            // select page
            /*if ($m_feed > 0)
            {
                $url_mask = SmotroonConfig::SEARCH_CATEGORY_MOVIE_LIST_PAGE_URL_FORMAT;
                $url = sprintf($url_mask, $category_id, $search_text, $m_feed);
            }
            else
            {
                $url_mask = SmotroonConfig::SEARCH_CATEGORY_MOVIE_LIST_URL_FORMAT;
                $url = sprintf($url_mask, $category_id, $search_text);
            }*/
        }
        else
        {
            // select page
            if ($m_feed > 0)
            {
                return $items;

                /*$url_mask = SmotroonConfig::SEARCH_MOVIE_LIST_PAGE_URL_FORMAT;
                $url = sprintf($url_mask, $search_text, $m_feed);*/
            }
            else
            {
                $url_mask = SmotroonConfig::SEARCH_MOVIE_LIST_URL_FORMAT;
                $url = sprintf($url_mask, $search_text);
            }
        }
        
        ++$m_feed;
        

        SmotroonApi::parse_search_page($url, $items, false, $plugin_cookies);
        
        return $items;
    }

    public static function get_search_category_id($category_ref, &$plugin_cookies)
    {
        return false;

        $url = 'http://www.smotroon.net' . $category_ref;
        try
        {
            $doc = HD::http_get_document($url);
        }
        catch(Exception $e)
        {
            throw self::smotroon_exception($e, 'No Internet');
        }
        
        $tmp = explode("<form name=search action='/search'>", $doc);
        if (count($tmp) < 2)
            return false;
            
        $tmp = explode("name=", $tmp[1]);
        if (count($tmp) < 2)
            return false;
            
        $var = strstr($tmp[1], " ", true);
        
        $tmp = explode("value='", $tmp[1]);
        if (count($tmp) < 2)
            return false;
            
        $value = strstr($tmp[1], "'", true);
        
        return "$var=$value";
    }

    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              VIDEO get movie by id
    //
    
    public static function get_movie_by_id($id, &$plugin_cookies)
    {
        $movies = array();
        self::parse_video_page($id, $movies, false, $plugin_cookies);
        
        return count($movies) > 0 ? $movies[0] : false;
    }

    ////////////////////////////////////////////////////////////////////////////////////
    //
    //              Misc functions
    //
    static function get_short_title($movie, $view_type)
    {
        $string = $movie->name;
        $year = $movie->year;
        $genres_str = $movie->genres_str;
        $has_new_series = $movie->has_new_series;
        
        $t = $string;
        
        /*$tmpTitle = explode('|', $string);
        if(count($tmpTitle)){
            $string = $tmpTitle[0];
        }*/

        $string = str_replace('|', '-', $string);
        
        $tmpTitle = explode('\\', $string);
        if(count($tmpTitle)){
            $string = $tmpTitle[0];
        }
        
        $string = self::clear($string);
        
    
        $video = self::video($t);
        
        $year = self::clear($year);
        
        $genres_str = self::clear($genres_str);
        
        $_year = empty($year) || $year == '-1' ? '' :' (' . $year . ')';
        
        $new_mark = '';
        if ($has_new_series)
            $new_mark = '[Н]';

        if ($view_type == 0)
        {
            $title = 'Название:';
            if (mb_strlen($string, "UTF-8") <= 20)
            {
                $title .= '|' . $string;
            }
            else
            {
                // split long titles for rows
                //hd_print("--->>> " . $string);
                $words = explode(' ', $string);
                $row = '';
                foreach($words as $word)
                {
                    //hd_print("---->>>>word: '$word'");
                    //hd_print("---->>>>len of row . word: '$row $word' " . (mb_strlen($row . $word, "UTF-8") + 1));
                    if (mb_strlen(trim($word), "UTF-8") == 0)
                        continue;
                    if ((mb_strlen($row . $word, "UTF-8") + 1) <= 20)
                    {
                        $row .= $word . ' ';
                    }
                    else
                    {
                        $title .= '|' . $row;
                        $row = $word . ' ';
                    }
                    //hd_print("---->>>>title: '$title'");
                    //hd_print("---->>>>row: '$row'");
                }
                //hd_print("---->>>>row: '$row'");
                if (mb_strlen(trim($row), "UTF-8") > 0)
                    $title .= '|' . $row;
            }
            
            if ($has_new_series)
                $title .= '|(Есть новые серии)';
            if (!empty($year) && $year != '-1')
                $title .= '||Год:|' . $year;
            
            /*$title .= '||Качество:|' . $video;
            if (strlen(trim($genres_str)) > 0)
            {
                $title .= '||Жанр:';
                $genres_list = explode(',', $genres_str);
                foreach($genres_list as $genre)
                {
                    $title .= '|' . trim($genre);
                }
            }
                        
            $title .= '||Продолжительность:|' . HD::format_duration(intval($movie->length_min) * 1000);*/
        }
        else
        {
            $title = $new_mark . $string . '|' . $_year ;//. $video. '|' . $genres_str;
        }
        
        return $title;
    }
    
    static function clear($str)
    {
        return str_replace(array("&quot;","&nbsp;","&#39;","8px' align=right>"), array("\""," ","'",""), $str);
    }
    
    static function video($string)
    {
        $video = ' ';

        if( preg_match('/[HD]/i',$string) ) {
            $video = ' [HD]';
        }
        return $video;
    }

    public static function retrieve_playback_url($url, &$plugin_cookies) {
        hd_print("---> 'Retrieve_playback_url'");

        // from config
        $stream_container = isset($plugin_cookies->stream_container) ? $plugin_cookies->stream_container : 'http-mp4';
        if (($i = stripos($url, 'http://mp4://')) !== false)
        {
            $url = urldecode(substr($url, strlen('http://mp4://')));
        }

        $new_url = false;

        if (    stripos($url, 'youtube.com') !== false) {
            $new_url = YouTube::getPlaybackUrl($url, $plugin_cookies);
        }
        elseif (stripos($url, 'vk.com/video_ext') !== false || stripos($url, 'vkontakte.ru/video_ext') !== false) {
            $new_url = VK::getPlaybackUrl($url, $plugin_cookies);
        }
        elseif (stripos($url, 'tvigle.ru') !== false && stripos($url, '.swf') !== false) {
            $new_url = Tvigle::getPlaybackUrl($url, $plugin_cookies);
        }
        elseif (stripos($url, 'veterok.tv') !== false) {
            $new_url = Veterok::getPlaybackUrl($url, $plugin_cookies);
        }
        elseif (stripos($url, 'mill.kz') !== false) {
            $new_url = Mill::getPlaybackUrl($url, $plugin_cookies);
        } else {
            hd_print("---> Can't find video extractor for $url");
            return false;
        }

        if ($new_url !== false) {

            if ( $stream_container === 'http-mp4') {
                $new_url = str_ireplace('http://', 'http://mp4://', $new_url);
            }

            if ( $stream_container === 'http-ts') {
                $new_url = str_ireplace('http://', 'http://ts://', $new_url);
            }

            hd_print("---> New_url = $new_url");
            return $new_url;
        }
        else {
            hd_print("---> Something was wrong when getting stream url");
            return false;
        }
    }

    public static function get_quality_array_vk($target_quality)
    {
        $quality = array();
        $quality['qb1080'] = 5;
        $quality['q1080'] = 4;
        $quality['q720'] = 3;
        $quality['q480'] = 2;
        $quality['q360'] = 1;
        $quality['q240'] = 0;

        $valid_quality = array();
        $valid_quality[0] = '240';
        $valid_quality[1] = '360';
        $valid_quality[2] = '480';
        $valid_quality[3] = '720';
        $valid_quality[4] = '1080';
        $valid_quality[5] = '1080';

        foreach($quality as $key => $value)
        {
            if ($key != $target_quality)
                unset($valid_quality[$value]);
            else
                return $valid_quality;
        }
        return $valid_quality;
    }

    public static function get_quality_array_youtube($target_quality)
    {
        $quality = array();

        $quality['qb1080'] = 'highres';
        $quality['q1080'] = 'hd1080';
        $quality['q720'] = 'hd720';
        $quality['q480'] = 'large';
        $quality['q360'] = 'medium';
        $quality['q240'] = 'small';

        $valid_quality = $quality;

        foreach($quality as $key => $value)
        {
            if ($key != $target_quality)
                unset($valid_quality[$key]);
            else
                return $valid_quality;
        }
        return $valid_quality;
    }

    public static function getUrlFromIframe($url)
    {
        if (($i = strpos($url, 'lazyload="')) !== false)
        {
            $url = substr($url, $i + strlen('lazyload="'));
            $url = strstr($url,'"', true);
            return $url;
        }
        if (($i = strpos($url, 'src="')) !== false)
        {
            $url = substr($url, $i + strlen('src="'));
            $url = strstr($url,'"', true);
            return $url;
        }
        return false;
    }

    public static function in_array_ci($needle, $haystack)
    {
        return in_array( strtolower($needle), array_map('strtolower', $haystack) );
    }
}

?>
