<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/abstract_controls_screen.php';
require_once 'skins/skins.php';

///////////////////////////////////////////////////////////////////////////

class SmotroonSetupScreen extends AbstractControlsScreen
{
    const ID = 'setup';
    
    public static function get_media_url_str()
    {
        return MediaURL::encode(
            array('screen_id' => self::ID));
    }
    private $skins;

    ///////////////////////////////////////////////////////////////////////

    public function __construct($skins)
    {
        parent::__construct(self::ID);
        $this->skins = $skins;
    }

    public function do_get_control_defs(&$plugin_cookies)
    {
        $defs = array();

        // Version
        ControlFactory::add_label
        (
            $defs,
            '',
            'Версия ' . SmotroonConfig::VERSION_MAJOR . '.' . SmotroonConfig::VERSION_MINOR . SmotroonConfig::VERSION_SUBMINOR . ' [' . SmotroonConfig::VERSION_DATE . ' ' . SmotroonConfig::VERSION_TIME . ']'
        );

        $show_ops = array();
        $show_ops['yes'] = 'Да';
        $show_ops['no'] = 'Нет';

        // Показывать Smotroon в главном меню:
        $main_icon = isset($plugin_cookies->main_icon) ? $plugin_cookies->main_icon : 'yes';
        $this->add_combobox
        (
            $defs,
            'show_main_icon',
            'Отображать иконку Смотрун в главном меню:',
            $main_icon, $show_ops, 0, true
        );

        // Использовать экранную клавиатуру в поиске
        $use_osk = isset($plugin_cookies->use_osk) ? $plugin_cookies->use_osk : 'yes';
        $this->add_combobox($defs,
                'use_osk',
                'Использовать экранную клавиатуру в поиске:',
                $use_osk, $show_ops, 0, true
            );
            
        // Время буферизации
        $buf_time = isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;
        $show_buf_time_ops = array();
        $show_buf_time_ops[0] = 'По умолчанию';
        $show_buf_time_ops[500] = '0.5 с';
        $show_buf_time_ops[1000] = '1 с';
        $show_buf_time_ops[2000] = '2 с';
        $show_buf_time_ops[3000] = '3 с';
        $show_buf_time_ops[5000] = '5 с';
        $show_buf_time_ops[10000] = '10 с';
        $show_buf_time_ops[20000] = '20 с';
        $show_buf_time_ops[30000] = '30 с';


        $this->add_combobox
        (
            $defs,
            'buf_time',
            'Время буферизации:',
            $buf_time, $show_buf_time_ops, 0, true
        );

        // Качество видео
        $video_quality = isset($plugin_cookies->video_quality) ? $plugin_cookies->video_quality : 'q720';
        $video_quality_ops = array();
        $video_quality_ops['q240'] = '240 (Минимально возможное)';
        $video_quality_ops['q360'] = '360';
        $video_quality_ops['q480'] = '480';
        $video_quality_ops['q720'] = '720';
        $video_quality_ops['q1080'] = '1080';
        $video_quality_ops['qb1080'] = '> 1080 (Максимально возможное)';

        $this->add_combobox
        (
            $defs,
            'video_quality',
            'Качество видео:',
            $video_quality, $video_quality_ops,  0, true
        );

        // Контейнер потока
        $stream_container = isset($plugin_cookies->stream_container) ? $plugin_cookies->stream_container : 'http-mp4';
        $stream_container_ops = array();
        $stream_container_ops['http-mp4'] = 'http://mp4://';
        $stream_container_ops['http-ts'] = 'http://ts://';

        $this->add_combobox
        (
            $defs,
            'stream_container',
            'Контейнер',
            $stream_container, $stream_container_ops, 0, true
        );

        // Частота запоминания позиции
        $play_timer = isset($plugin_cookies->play_timer) ? $plugin_cookies->play_timer : 5000;
        $play_timer_ops = array();
        $play_timer_ops[0] = 'Не запоминать';
        $play_timer_ops[1000] = '1 сек.';
        $play_timer_ops[5000] = '5 сек.';
        $play_timer_ops[10000] = '10 сек.';
        $play_timer_ops[15000] = '15 сек.';
        $play_timer_ops[20000] = '20 сек.';
        $play_timer_ops[30000] = '30 сек.';
        $play_timer_ops[60000] = '60 сек.';

        $this->add_combobox
        (
            $defs,
            'play_timer',
            'Частота запоминания позиции:',
            $play_timer, $play_timer_ops, 0, true
        );

        // Оформление
        $skin_ops = array();
        $skins = $this->skins->get_skin_names();
        foreach ($skins as $s)
        {
            hd_print('--->>> skin path: ' . $s['name_idx']);
            hd_print('--->>> skin name: ' . $s['name']);
            $skin_ops[$s['name_idx']] = $s['name'];
        }

        $skin = isset($plugin_cookies->skin) ? $plugin_cookies->skin : 'build_in';
        $this->add_combobox
        (
            $defs,
            'skin',
            'Оформление (требуется перезагрузка):',
            $skin, $skin_ops, 0, true
        );

        $this->add_button
        (
            $defs,
            'restart',
            '',
            'Перезагрузить плеер',
            0
        );
        return $defs;
    }

    public function get_control_defs(MediaURL $media_url, &$plugin_cookies)
    {
        return $this->do_get_control_defs($plugin_cookies);
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Setup: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if (!isset($user_input->control_id))
            return null;

        $control_id = $user_input->control_id;
        $new_value = $user_input->{$control_id};
        
        if ($user_input->control_id === 'buf_time')
            $plugin_cookies->buf_time = $new_value;
        else if ($user_input->control_id === 'show_main_icon')
            $plugin_cookies->main_icon = $new_value;
        else if ($user_input->control_id === 'use_osk')
            $plugin_cookies->use_osk = $new_value;
        else if ($user_input->control_id === 'play_timer')
            $plugin_cookies->play_timer = $new_value;
        else if ($user_input->control_id === 'stream_container')
            $plugin_cookies->stream_container = $new_value;
        else if ($user_input->control_id === 'video_quality')
            $plugin_cookies->video_quality = $new_value;
        else if ($control_id === 'skin')
        {
            $plugin_cookies->skin = $new_value;
            $this->skins->update_main_icons($plugin_cookies);
        }
        else if ($control_id === 'restart')
            shell_exec('killall shell');

        return ActionFactory::reset_controls(
            $this->do_get_control_defs($plugin_cookies));
    }
}

///////////////////////////////////////////////////////////////////////////
?>
