<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/abstract_preloaded_regular_screen.php';

require_once 'Smotroon_vod_category.php';
require_once 'Smotroon_vod_list_screen.php';
require_once 'Smotroon_api.php';

///////////////////////////////////////////////////////////////////////////

class SmotroonVodCategoryListScreen extends AbstractPreloadedRegularScreen implements UserInputHandler
{
    const ID = 'vod_category_list';

    public static function get_media_url_str($category_id, $items_count)
    {
        return  MediaURL::encode
                (
                    array
                    (
                        'screen_id'     => self::ID,
                        'category_id'   => $category_id,
                        'items_count'   => $items_count,
                    )
                );
    }

    ///////////////////////////////////////////////////////////////////////

    private $category_list;
    private $category_index;
    
    private $skins;
    
    ///////////////////////////////////////////////////////////////////////

    public function __construct($skins)
    {
        parent::__construct(self::ID);
        
        $this->skins = $skins;

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    public function get_handler_id()
    { return self::ID; }
    ///////////////////////////////////////////////////////////////////////

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $search = UserInputHandlerRegistry::create_action($this, 'search');
        $search['caption'] = 'Общий поиск';

        return array(
            GUI_EVENT_KEY_ENTER => ActionFactory::open_folder(),
            GUI_EVENT_KEY_D_BLUE => $search,
        );
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('vod_category_list: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");
            
        switch ($user_input->control_id)
        {
        case 'search':
            $url = Smotroon_search_history::get_media_url_str();
            return ActionFactory::open_folder($url, 'Поиск');

        default:
            $this->category_index = null;
            $plugin_cookies->vod_language = $user_input->control_id;
            return ActionFactory::invalidate_folders(array($user_input->parent_media_url), null);
        }
        
        return null;
    }
    ///////////////////////////////////////////////////////////////////////

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        if (is_null($this->category_index))
            $this->fetch_vod_categories($plugin_cookies);

        $category_list = $this->category_list;

        $skin = $this->skins->get_current_skin($plugin_cookies);
      
        $items = array();

        foreach ($category_list as $c)
        {
            $media_url_str = SmotroonVodListScreen::get_media_url_str($c->get_ref());

            $items[] = array
            (
                PluginRegularFolderItem::media_url => $media_url_str,
                PluginRegularFolderItem::caption => $c->get_caption(),
                PluginRegularFolderItem::view_item_params => $skin->get_category_items_view_params($plugin_cookies),
            );
        }

        return $items;
    }

    ///////////////////////////////////////////////////////////////////////

    private function fetch_vod_categories(&$plugin_cookies)
    {
        $this->category_index = array();
        if (!isset($plugin_cookies->vod_language))
            $plugin_cookies->vod_language = 'vod_categories';
        $language = $plugin_cookies->vod_language;
        $this->category_list = SmotroonApi::get_categories($language, $this->category_index);
        if (!$this->category_list)
            $this->category_index = null;
    }

    ///////////////////////////////////////////////////////////////////////


    protected function do_get_folder_views(&$plugin_cookies)
    {
        return $this->skins->get_current_skin($plugin_cookies)->GET_VOD_CATEGORY_LIST_FOLDER_VIEWS($plugin_cookies);
    }
}

///////////////////////////////////////////////////////////////////////////
?>
